from setuptools import setup

def readme():
    with open('README.md') as f:
        README = f.read()
    return README
setup(
    name='Outliers_101703296_thapar',
    version='1.0.1',
    description='A row outlier removal Package Project of UCS633',
    author='Kuljot Singh Saggu',
    author_email='kuljot2216@gmail.com',
    long_description="This package has been created based on Project 2 of course UCS633."
    "Kuljot Singh Saggu COE14 101703296",
    license='MIT',
    classifiers=[
        "Programming Language :: Python",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: Python Software Foundation License",
    ],
    packages=["outliers_101703296"],
    include_package_data=True,
    entry_points = {
        "console_scripts": [
            "Outliers_101703296_thapar= outliers_101703296.remove_outliers:main",
        ]
    },
    )



import pandas as pd
import numpy as np
from scipy import stats
import sys

def delete_outliers(ds,z_val=3):
    if ds.ndim>2:
        out_ds = ds[(np.abs(stats.zscore(ds)) < z_val).all(axis=1)]
    else:
        out_ds = ds[(np.abs(stats.zscore(ds)) < z_val)]
    return (out_ds,len(ds)-len(out_ds))            


def main():
    filename = sys.argv[1]
    try:
        data = pd.read_csv(filename)
    except OSError:
        print('cannot open', filename)
        sys.exit(0)
        
    (data,count) = delete_outliers(data)
    
    try:
        data.to_csv("out.csv",index=False)
        print("number of rows deleted: ",count)    
    except OSError:
        print('cannot open', filename)
        sys.exit(0)
        
if __name__=="__main__":
    main()